@@ -84,6 +84,10 @@ SPIRVEntry *SPIRVEntry::create(Op OpCode) {
   static const OpToFactoryMapTy OpToFactoryMap(std::begin(Table),
                                                std::end(Table));
 
+  // TODO: To remove this when we make a switch to new version
+  if (OpCode == internal::OpTypeJointMatrixINTELv2)
+    OpCode = internal::OpTypeJointMatrixINTEL;
+
   OpToFactoryMapTy::const_iterator Loc = OpToFactoryMap.find(OpCode);
   if (Loc != OpToFactoryMap.end())
     return Loc->second();
@@ -263,7 +267,7 @@ SPIRVEntry::getValueTypes(const std::vector<SPIRVId> &IdVec) const {
 std::vector<SPIRVId>
 SPIRVEntry::getIds(const std::vector<SPIRVValue *> ValueVec) const {
   std::vector<SPIRVId> IdVec;
-  for (auto I : ValueVec)
+  for (auto *I : ValueVec)
     IdVec.push_back(I->getId());
   return IdVec;
 }
@@ -342,9 +346,9 @@ void SPIRVEntry::setDebugLine(const std::shared_ptr<const SPIRVExtInst> &DL) {
 }
 
 void SPIRVEntry::addMemberDecorate(SPIRVMemberDecorate *Dec) {
-  assert(canHaveMemberDecorates() &&
-         MemberDecorates.find(Dec->getPair()) == MemberDecorates.end());
-  MemberDecorates[Dec->getPair()] = Dec;
+  assert(canHaveMemberDecorates());
+  MemberDecorates.insert(std::make_pair(
+      std::make_pair(Dec->getMemberNumber(), Dec->getDecorateKind()), Dec));
   Module->addDecorate(Dec);
   SPIRVDBG(spvdbgs() << "[addMemberDecorate] " << *Dec << '\n';)
 }
@@ -440,6 +444,33 @@ SPIRVEntry::getMemberDecorationStringLiteral(Decoration Kind,
   return getVecString(Loc->second->getVecLiteral());
 }
 
+std::vector<std::vector<std::string>>
+SPIRVEntry::getAllDecorationStringLiterals(Decoration Kind) const {
+  auto Loc = Decorates.find(Kind);
+  if (Loc == Decorates.end())
+    return {};
+
+  std::vector<std::vector<std::string>> Literals;
+  auto It = Decorates.equal_range(Kind);
+  for (auto Itr = It.first; Itr != It.second; ++Itr)
+    Literals.push_back(getVecString(Itr->second->getVecLiteral()));
+  return Literals;
+}
+
+std::vector<std::vector<std::string>>
+SPIRVEntry::getAllMemberDecorationStringLiterals(Decoration Kind,
+                                                 SPIRVWord MemberNumber) const {
+  auto Loc = MemberDecorates.find({MemberNumber, Kind});
+  if (Loc == MemberDecorates.end())
+    return {};
+
+  std::vector<std::vector<std::string>> Literals;
+  auto It = MemberDecorates.equal_range({MemberNumber, Kind});
+  for (auto Itr = It.first; Itr != It.second; ++Itr)
+    Literals.push_back(getVecString(Itr->second->getVecLiteral()));
+  return Literals;
+}
+
 std::vector<SPIRVWord>
 SPIRVEntry::getDecorationLiterals(Decoration Kind) const {
   auto Loc = Decorates.find(Kind);
@@ -615,9 +646,7 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   getDecoder(I) >> Target >> ExecMode;
   switch (static_cast<uint32_t>(ExecMode)) {
   case ExecutionModeLocalSize:
-  case ExecutionModeLocalSizeId:
   case ExecutionModeLocalSizeHint:
-  case ExecutionModeLocalSizeHintId:
   case ExecutionModeMaxWorkgroupSizeINTEL:
     WordLiterals.resize(3);
     break;
@@ -636,12 +665,11 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   case ExecutionModeSharedLocalMemorySizeINTEL:
   case ExecutionModeNamedBarrierCountINTEL:
   case ExecutionModeSubgroupSize:
-  case ExecutionModeSubgroupsPerWorkgroup:
-  case ExecutionModeSubgroupsPerWorkgroupId:
   case ExecutionModeMaxWorkDimINTEL:
   case ExecutionModeNumSIMDWorkitemsINTEL:
   case ExecutionModeSchedulerTargetFmaxMhzINTEL:
-  case internal::ExecutionModeStreamingInterfaceINTEL:
+  case ExecutionModeRegisterMapInterfaceINTEL:
+  case ExecutionModeStreamingInterfaceINTEL:
   case internal::ExecutionModeMaximumRegistersINTEL:
   case internal::ExecutionModeMaximumRegistersIdINTEL:
   case internal::ExecutionModeNamedMaximumRegistersINTEL:
